import { ExpressionNode } from './parser';
import { IContext } from 'common';
/**
 * A parsed context expression (that can evaluate to anything)
 */
export declare class Expression<T> {
    private root;
    constructor(root: ExpressionNode);
    exec<C>(context: IContext): T;
}
/**
 * A parsed template string that can contain `${contextKey}` interpolations.
 * Always evaluates to a string.
 */
export declare class TemplateExpression<S extends string = string> extends Expression<S> {
}
/**
 * Evaluates an expression with the given context and returns the result.
 */
export declare function parse<T>(expression: string): Expression<T>;
/**
 * Evaluates a template with the given context and returns the result.
 *
 * A template is a string that interpolates expressions in ${...}. It uses the same syntax as
 * JavaScript templates.
 */
export declare function parseTemplate(template: string): TemplateExpression;
