import { IMarkdownString } from '@vscode-alt/monaco-editor/esm/vs/base/common/htmlContent';
import { UriComponents } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { IRange } from '@vscode-alt/monaco-editor/esm/vs/editor/common/core/range';
import { ThemeColor } from '@vscode-alt/monaco-editor/esm/vs/platform/theme/common/themeService';
import { TrackedRangeStickiness, OverviewRulerLane } from '@vscode-alt/monaco-editor/esm/vs/editor/common/model';
/**
 * @internal
 */
export interface IContentDecorationRenderOptions {
    contentText?: string;
    contentIconPath?: string | UriComponents;
    border?: string;
    borderColor?: string | ThemeColor;
    fontStyle?: string;
    fontWeight?: string;
    textDecoration?: string;
    color?: string | ThemeColor;
    backgroundColor?: string | ThemeColor;
    margin?: string;
    width?: string;
    height?: string;
}
/**
 * @internal
 */
export interface IThemeDecorationRenderOptions {
    backgroundColor?: string | ThemeColor;
    outline?: string;
    outlineColor?: string | ThemeColor;
    outlineStyle?: string;
    outlineWidth?: string;
    border?: string;
    borderColor?: string | ThemeColor;
    borderRadius?: string;
    borderSpacing?: string;
    borderStyle?: string;
    borderWidth?: string;
    fontStyle?: string;
    fontWeight?: string;
    textDecoration?: string;
    cursor?: string;
    color?: string | ThemeColor;
    opacity?: number;
    letterSpacing?: string;
    gutterIconPath?: string | UriComponents;
    gutterIconSize?: string;
    overviewRulerColor?: string | ThemeColor;
    before?: IContentDecorationRenderOptions;
    after?: IContentDecorationRenderOptions;
}
/**
 * @internal
 */
export interface IDecorationRenderOptions extends IThemeDecorationRenderOptions {
    isWholeLine?: boolean;
    rangeBehavior?: TrackedRangeStickiness;
    overviewRulerLane?: OverviewRulerLane;
    light?: IThemeDecorationRenderOptions;
    dark?: IThemeDecorationRenderOptions;
}
/**
 * @internal
 */
export interface IThemeDecorationInstanceRenderOptions {
    before?: IContentDecorationRenderOptions;
    after?: IContentDecorationRenderOptions;
}
/**
 * @internal
 */
export interface IDecorationInstanceRenderOptions extends IThemeDecorationInstanceRenderOptions {
    light?: IThemeDecorationInstanceRenderOptions;
    dark?: IThemeDecorationInstanceRenderOptions;
}
/**
 * @internal
 */
export interface IDecorationOptions {
    range: IRange;
    hoverMessage?: IMarkdownString | IMarkdownString[];
    renderOptions?: IDecorationInstanceRenderOptions;
}
export declare enum EditorPosition {
    ONE = 0,
    TWO = 1,
    THREE = 2
}
